/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.cassandra.sidecar.common.response;

import java.util.Arrays;
import java.util.stream.Stream;

import com.google.common.base.CaseFormat;
import com.google.common.base.Converter;
import org.junit.jupiter.params.ParameterizedTest;
import org.junit.jupiter.params.provider.Arguments;
import org.junit.jupiter.params.provider.MethodSource;

import static org.junit.jupiter.params.provider.Arguments.arguments;
import static org.assertj.core.api.Assertions.assertThat;

/**
 * Unit tests for the upper underscore case conversion to lower camel case
 */
class GossipInfoResponseTest
{
    static final Converter<String, String> CASE_CONVERTER = CaseFormat.UPPER_UNDERSCORE
                                                            .converterTo(CaseFormat.LOWER_CAMEL);

    @ParameterizedTest(name = "{index} => gossipField={0}, expectedValue={1}")
    @MethodSource(value = { "gossipFields" })
    void testLowerCamelCase(GossipInfoResponse.GossipField gossipField, String expectedValue)
    {
        assertThat(gossipField.toLowerCamelCase()).isEqualTo(expectedValue);
    }

    static Stream<Arguments> gossipFields()
    {
        return Arrays.stream(GossipInfoResponse.GossipField.values())
                     .map(field -> arguments(field, CASE_CONVERTER.convert(field.name())));
    }
}
